
#=============================================================================================

# Uma estimativa da incerteza na previsão do modelo

data = read.table("babies.txt", header=TRUE)

# Preparação e remoção de NA's
data[ data$gestation == 999, 2 ] = NA
data = data[complete.cases(data), ]

# Conversão do peso para Kg
bwt = data$bwt * 0.0283495

model = lm(bwt ~ data$gestation)

# Cálculo do erro
ssx = sum((data$gestation - mean(data$gestation))^2)
vt = seq(min(data$gestation), max(data$gestation), length.out=100)
se = sqrt((var(bwt)) * ((1/length(bwt)) + (((vt - mean(data$gestation)) ^ 2)/ssx)))

t = qt(0.975, (length(bwt) - 2))

vt.model = coef(model)[1] + vt * coef(model)[2]

vt.model.p = vt.model + (se * t)
vt.model.n = vt.model - (se * t)

plot(bwt ~ data$gestation, xlab="Duração da gestação (dias)", ylab="Massa ao nascer (kg)")
abline(model, col="blue")

lines(vt, vt.model.p, col="red")
lines(vt, vt.model.n, col="green")

#=============================================================================================

# Galileu estava Certo?

init.h = c(600, 700, 800, 950, 1100, 1300, 1500)
h.d = c(253, 337, 395, 451, 495, 534, 573)

plot(h.d ~ init.h)

mod1 <- lm(h.d ~ init.h)
mod2 <- update(mod1, .~. + I(init.h ^ 2))

anova(mod1, mod2)

abline(mod1)

cf.m2 <- coef(mod2)
curve(cf.m2[1] +
	cf.m2[2] * x +
	cf.m2[3] * (x ^ 2),
	add = T, lty = 2, col = "blue")

summary(mod2)

mod3 = lm(h.d ~ init.h + I(init.h ^ 2) + I(init.h ^ 3))
anova(mod2, mod3)

cf.m3 <- coef(mod3)
curve(cf.m3[1] +
	cf.m3[2] * x +
	cf.m3[3] * (x ^ 2) +
	cf.m3[4] * (x ^ 3),
	col = "red", add = T, lty = 2)

#=============================================================================================

data = read.table("babies.txt", header = TRUE)

data[data$gestation == 999, 2] = NA
data[data$age == 99, 4] = NA
data[data$height == 99, 5] = NA
data[data$weight == 999, 6] = NA
data[data$smoke == 9, 7] = NA

data = data[complete.cases(data),]
data$parity = as.factor(data$parity)
data$smoke = as.factor(data$smoke)

model1 = lm(bwt ~ gestation + parity + age + height + weight + smoke +
	gestation:age + gestation:smoke +
	I(gestation^2) + I(age^2) + I(height^2) + I(weight^2), data = data)

summary(model1)

model2 = lm(bwt ~ gestation + parity + age + height + weight + smoke +
	gestation:age + gestation:smoke +
	I(gestation^2) + I(height^2) + I(weight^2), data = data)

anova(model1, model2)
summary(model2)

model3 = lm(bwt ~ gestation + parity + age + height + weight + smoke +
	gestation:age + gestation:smoke +
	I(gestation^2) + I(height^2), data = data)

anova(model2, model3)
summary(model3)

model4 = lm(bwt ~ parity + age + height + weight + smoke +
	gestation:age + gestation:smoke +
	I(gestation^2) + I(height^2), data = data)

anova(model3, model4)
summary(model4)

model5 = lm(bwt ~ parity + age + height + weight + smoke +
	gestation:age + gestation:smoke +
	I(height^2), data = data)

anova(model4, model5)
summary(model5)

model6 = lm(bwt ~ parity + age + height + smoke +
	gestation:age + gestation:smoke +
	I(height^2), data = data)

anova(model5, model6)
summary(model6)

# Modelo mínimo final selecionado
model7 = lm(bwt ~ parity + age + smoke +
	gestation:age + gestation:smoke +
	I(height^2), data = data)

anova(model6, model7)
summary(model7)

anova(model7)

#=============================================================================================
